@@ -2,18 +2,23 @@ package Catalyst::Controller::HTML::FormFu::Action::FormMethod;
 
 use strict;
 use warnings;
-use base qw( Catalyst::Action );
+use base qw( Catalyst::Controller::HTML::FormFu::ActionBase::Form );
 
-use NEXT;
+use MRO::Compat;
 use Carp qw( croak );
 
 sub execute {
     my $self = shift;
     my ( $controller, $c ) = @_;
 
+    if ( $self->reverse =~ $self->_form_action_regex ) {
+        # don't load form again
+        return $self->next::method(@_);
+    }
+
     my $config = $controller->_html_formfu_config;
 
-    return $self->NEXT::execute(@_)
+    return $self->next::method(@_)
         unless exists $self->attributes->{ActionClass}
             && $self->attributes->{ActionClass}[0] eq $config->{method_action};
 
@@ -33,7 +38,7 @@ sub execute {
 
     $c->stash->{ $config->{form_stash} } = $form;
 
-    $self->NEXT::execute(@_);
+    $self->next::method(@_);
 }
 
 1;
